''' https://en.wikipedia.org/wiki/Avoirdupois US Customary units: https://en.wikipedia.org/wiki/United_States_customary_units https://simple.wikipedia.org/wiki/United_States_customary_units mass: avoirdupois: ton = 2000 POUNDS cwt (SHORT HUNDREDWEIGHT) = 100 POUNDS qr (QUARTER) = 25 POUNDS AVOIRDUPOIS POUND: lb (POUND) oz (OUNCE) = 1/16 POUND DRAM = 1/256 POUND grain = 1/7000 POUND TROY: POUND: OUNCE: = 1/12 POUNDS PENNYWEIGHT: GRAIN: FLUID VOLUME: AREA: 1 SQUARE SURVEY FOOT: 1 SQUARE CHAIN: 1 ACRE: 1 SECTION: 1 SURVEY TOWNSHIP: '''